@@ -1,5 +1,3 @@
-# TODO: Is it ok to use the same person in the train as the test? Even if they are from different debates. Maybe work on this in the future
-
 import argparse
 import multiprocessing
 from collections import defaultdict, Counter
@@ -25,6 +23,8 @@ def get_percentages(d):
 
 
 def main():
+    print('Warning: the member data is included in the party data so members with a lot of speech data will squeue. Don\'t trust this too much')
+    # TODO: only allow for doing per member and having the party they're in have the member's data removed so we can be accurate
 
     parser = argparse.ArgumentParser()
     parser.add_argument("--epochs", dest="epochs", type=int, default=25)
